Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(329)

Unified Diff: components/user_manager/user_manager_base.h

Issue 718673002: New user type introduced. Combines regular and supervised features. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Logical expression fixed. Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/user_manager/user_manager_base.h
diff --git a/components/user_manager/user_manager_base.h b/components/user_manager/user_manager_base.h
index 49a287f37cfb7db4cc88bb72fb2bc3d7b1e7dbd3..7cf9ecc6b4e688e76b47983090a728a521fac8a4 100644
--- a/components/user_manager/user_manager_base.h
+++ b/components/user_manager/user_manager_base.h
@@ -86,7 +86,8 @@ class USER_MANAGER_EXPORT UserManagerBase : public UserManager {
virtual bool IsCurrentUserNonCryptohomeDataEphemeral() const override;
virtual bool CanCurrentUserLock() const override;
virtual bool IsUserLoggedIn() const override;
- virtual bool IsLoggedInAsRegularUser() const override;
+ virtual bool IsLoggedInAsUserWithGaiaAccount() const override;
+ virtual bool IsLoggedInAsRegularSupervisedUser() const override;
virtual bool IsLoggedInAsDemoUser() const override;
virtual bool IsLoggedInAsPublicAccount() const override;
virtual bool IsLoggedInAsGuest() const override;
@@ -307,8 +308,8 @@ class USER_MANAGER_EXPORT UserManagerBase : public UserManager {
// Insert |user| at the front of the LRU user list.
void SetLRUUser(User* user);
- // Sends metrics in response to a regular user logging in.
- void SendRegularUserLoginMetrics(const std::string& user_id);
+ // Sends metrics in response to a user with gaia account (regular) logging in.
bartfab (slow) 2014/11/27 12:51:51 Nit 1: s/gaia/a gaia/ Nit 2: I am not sure the "re
+ void SendGaiaUserLoginMetrics(const std::string& user_id);
// Sets account locale for user with id |user_id|.
virtual void UpdateUserAccountLocale(const std::string& user_id,

Powered by Google App Engine
This is Rietveld 408576698